==> 0.3.4%2B3.tar.gz: lib/entity/entity.dart <==
part of viltage;

class Entity {
	int layer;
	int x, y;
	int width, height;
	int activeState = 0;
	int activeAnimation = -1;
	bool visible = true;
	bool active = true;
	bool destructible = true;
	
	List<Collidable> collidables = new List<Collidable>();
  List<VilTAGEAnimation> animations = new List<VilTAGEAnimation>();
	List<State> states = new List<State>();
	  
  Entity(this.x, this.y, this.layer, var screen) {
    if(screen is VilTAGE) screen..getScreen().entities[layer].add(this);
    else screen.entities[layer].add(this);
  	states.add(new State());
  }
  
	render(List<List<Node>> nodeArray) {
	  if(visible) states[activeState].render(x, y, nodeArray);
	}

  setQuantity(int quantity) {
    if(quantity > states.length) {
      while(quantity < states.length) {
        states.add(new State());
      }
    } else {
      while(quantity > states.length) {
        states.removeLast();
      }
    }
  }
	
	update(double delta) { }
	
	updateAnimations(double delta) {
		if(activeAnimation != -1 && activeAnimation < animations.length) {
  	  animations[activeAnimation].update(delta);
      activeState = animations[activeAnimation].sequence[animations[activeAnimation].current];
  	} else activeState = 0;
	}

	remove(var screen) {
		if(screen is VilTAGE) screen.getScreen().entitiesToRemove.add(this);
		else screen.entitiesToRemove.add(this);
	}
	
	static List<List<Collidable>> testCollision(Entity e1, Entity e2) {
	  List<List<Collidable>> list = new List<List<Collidable>>();
	  for(int i = 0; i < e1.collidables.length; i++) {
	    for(int j = 0; j < e2.collidables.length; j++) {
	      if(Collidable.collides(e1.x, e1.y, e2.x, e2.y, e1.collidables[i], e2.collidables[j])) list.add([e1.collidables[i], e2.collidables[j]]);
	    }
	  }
	  if(list.length == 0) return null;
	  else return list;
	}

	static clear(var screenObject) {
	  VilTAGEScreen screen;
	  if(screenObject is VilTAGE) screen = screenObject.getScreen();
	  else screen = screenObject;
	  
	  if(screen.entities==null) {
       screen.entities = new List<List<Entity>>();
       for(int i = 0; i < 20; i++) {
         screen.entities.add(new List<Entity>());
       }
     } else {
       for(int i = 0; i < screen.entities.length; i++) {
  			 List<Entity> entityToRemove = new List<Entity>();
  			 for(Entity e in screen.entities[i]) {
    		   if(e.destructible) entityToRemove.add(e);
    		 }
  			 for(Entity e in entityToRemove) {
  			   screen.entities[i].remove(e);
           e.remove(screen);
  			 }
      }
		}
		
		Entity e = new Entity(0, 0, 0, screen);
		for(int i = 0; i < screen.viltage.width; i++) {
			for(int j = 0; j < screen.viltage.height; j++) {
				e.states[0].createCharNode(i, j, screen.viltage.backgroundChar);
			}
		}
	}
}

==> 0.3.5%2B3.tar.gz: lib/entity/entity.dart <==
part of viltage;

class Entity {
	int layer;
	int x, y;
	int width, height;
	int activeState = 0;
	int activeAnimation = -1;
	bool visible = true;
	bool active = true;
	bool destructible = true;
	
	List<Collidable> collidables = new List<Collidable>();
  List<VilTAGEAnimation> animations = new List<VilTAGEAnimation>();
	List<State> states = new List<State>();
	  
  Entity(this.x, this.y, this.layer, var screen) {
    if(screen is VilTAGE) screen..getScreen().entities[layer].add(this);
    else screen.entities[layer].add(this);
  	states.add(new State());
  }
  
	render(List<List<Node>> nodeArray) {
	  if(visible) states[activeState].render(x, y, nodeArray);
	}

  setStatesQuantity(int quantity) {
    while(quantity < states.length) {
      states.removeLast();
    }
    while(quantity > states.length) {
      states.add(new State());
    }
    if(activeState >= states.length) visible = false;
  }
	
	update(double delta) { }
	
	updateAnimations(double delta) {
		if(activeAnimation != -1 && activeAnimation < animations.length) {
  	  animations[activeAnimation].update(delta);
      activeState = animations[activeAnimation].sequence[animations[activeAnimation].current];
  	}
	}

	remove(var screen) {
		if(screen is VilTAGE) screen.getScreen().entitiesToRemove.add(this);
		else screen.entitiesToRemove.add(this);
	}
	
	static List<List<Collidable>> testCollision(Entity e1, Entity e2) {
	  List<List<Collidable>> list = new List<List<Collidable>>();
	  for(int i = 0; i < e1.collidables.length; i++) {
	    for(int j = 0; j < e2.collidables.length; j++) {
	      if(Collidable.collides(e1.x, e1.y, e2.x, e2.y, e1.collidables[i], e2.collidables[j])) list.add([e1.collidables[i], e2.collidables[j]]);
	    }
	  }
	  if(list.length == 0) return null;
	  else return list;
	}

	static clear(var screenObject) {
	  VilTAGEScreen screen;
	  if(screenObject is VilTAGE) screen = screenObject.getScreen();
	  else screen = screenObject;
	  
	  if(screen.entities==null) {
       screen.entities = new List<List<Entity>>();
       for(int i = 0; i < 20; i++) {
         screen.entities.add(new List<Entity>());
       }
     } else {
       for(int i = 0; i < screen.entities.length; i++) {
  			 List<Entity> entityToRemove = new List<Entity>();
  			 for(Entity e in screen.entities[i]) {
    		   if(e.destructible) entityToRemove.add(e);
    		 }
  			 for(Entity e in entityToRemove) {
  			   screen.entities[i].remove(e);
           e.remove(screen);
  			 }
      }
		}
		
		Entity e = new Entity(0, 0, 0, screen);
		for(int i = 0; i < screen.viltage.width; i++) {
			for(int j = 0; j < screen.viltage.height; j++) {
				e.states[0].createCharNode(i, j, " ")..backgroundColor=screen.viltage.backgroundChar;
			}
		}
	}
}
